==> xts-0.99.0.tar.bz2: xts-0.99.0/xts5/src/lib/cursor.c <==
/*
Copyright (c) 2005 X.Org Foundation L.L.C.

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
/*
*
* Copyright Applied Testing and Technology Inc. 1995
* All rights reserved
*
* Project: VSW5
*
* File:	xts5/src/lib/cursor.c
*
* Description:
*	Cursor support routines
*
* Modifications:
* $Log: cursor.c,v $
* Revision 1.2  2005-11-03 08:42:01  jmichael
* clean up all vsw5 paths to use xts5 instead.
*
* Revision 1.1.1.2  2005/04/15 14:05:09  anderson
* Reimport of the base with the legal name in the copyright fixed.
*
* Revision 8.0  1998/12/23 23:24:30  mar
* Branch point for Release 5.0.2
*
* Revision 7.0  1998/10/30 22:42:41  mar
* Branch point for Release 5.0.2b1
*
* Revision 6.0  1998/03/02 05:16:55  tbr
* Branch point for Release 5.0.1
*
* Revision 5.0  1998/01/26 03:13:28  tbr
* Branch point for Release 5.0.1b1
*
* Revision 4.1  1996/01/25 01:57:14  andy
* Portability improvements from DEPLOY tools
*
* Revision 4.0  1995/12/15  08:42:06  tbr
* Branch point for Release 5.0.0
*
* Revision 3.1  1995/12/15  00:39:15  andy
* Prepare for GA Release
*
*/

/*
Portions of this software are based on Xlib and X Protocol Test Suite.
We have used this material under the terms of its copyright, which grants
free use, subject to the conditions below.  Note however that those
portions of this software that are based on the original Test Suite have
been significantly revised and that all such revisions are copyright (c)
1995 Applied Testing and Technology, Inc.  Insomuch as the proprietary
revisions cannot be separated from the freely copyable material, the net
result is that use of this software is governed by the ApTest copyright.

Copyright (c) 1990, 1991  X Consortium

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of the X Consortium shall not be
used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from the X Consortium.

Copyright 1990, 1991 by UniSoft Group Limited.

Permission to use, copy, modify, distribute, and sell this software and
its documentation for any purpose is hereby granted without fee,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of UniSoft not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.  UniSoft
makes no representations about the suitability of this software for any
purpose.  It is provided "as is" without express or implied warranty.
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include	"xtest.h"
#include	"X11/Xlib.h"
#include	"X11/Xutil.h"
#include	"xtestlib.h"
#include	"pixval.h"

/* does this cursor match that of the window? */

curofwin(display, cursor, window)
Display	*display;
Cursor	cursor;
Window	window;
{
	return CompareCursorWithWindow(display, window, cursor);
}

/* has this window the default cursor? */

defcur(display, window)
Display	*display;
Window	window;
{
	Window root, wjunk, withdefault;
	int ijunk, rx, ry, res;
	unsigned int ujunk;

	if (!XQueryPointer(display, window, &root, &wjunk,
			&rx, &ry, &ijunk, &ijunk, &ujunk)) {
		delete("pointer not on same screen as window 0x%x.",
				(unsigned)window);
		return False;
	}
	withdefault = crechild(display, root, (struct area *)NULL);
	/* that window should have default Cursor, whatever that is */

	/*
	 * Note if a grab is active with a cursor specified then that's what
	 * we've got instead of our nice default cursor, so we fail.
	 * Also, if confine_to & grab then we may not get to our nice new
	 * window.
         * DO NOT USE THIS WHEN GRABS ARE ACTIVE.
	 */
	XWarpPointer(display, None, withdefault, 0, 0, 0, 0, 1, 1);
	res = CompareCurrentWithWindow(display, window);
	XWarpPointer(display, None, root, 0, 0, 0, 0, rx, ry);
	return res;
}

/* is the current cursor the same as that of window? */

spriteiswin(display, window)
Display	*display;
Window	window;
{
	return CompareCurrentWithWindow(display, window);
}

==> xts-0.99.1.tar.bz2: xts-0.99.1/xts5/src/lib/cursor.c <==
/*
Copyright (c) 2005 X.Org Foundation L.L.C.

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
/*
*
* Copyright Applied Testing and Technology Inc. 1995
* All rights reserved
*
* Project: VSW5
*
* File:	xts5/src/lib/cursor.c
*
* Description:
*	Cursor support routines
*
* Modifications:
* $Log: cursor.c,v $
* Revision 1.2  2005-11-03 08:42:01  jmichael
* clean up all vsw5 paths to use xts5 instead.
*
* Revision 1.1.1.2  2005/04/15 14:05:09  anderson
* Reimport of the base with the legal name in the copyright fixed.
*
* Revision 8.0  1998/12/23 23:24:30  mar
* Branch point for Release 5.0.2
*
* Revision 7.0  1998/10/30 22:42:41  mar
* Branch point for Release 5.0.2b1
*
* Revision 6.0  1998/03/02 05:16:55  tbr
* Branch point for Release 5.0.1
*
* Revision 5.0  1998/01/26 03:13:28  tbr
* Branch point for Release 5.0.1b1
*
* Revision 4.1  1996/01/25 01:57:14  andy
* Portability improvements from DEPLOY tools
*
* Revision 4.0  1995/12/15  08:42:06  tbr
* Branch point for Release 5.0.0
*
* Revision 3.1  1995/12/15  00:39:15  andy
* Prepare for GA Release
*
*/

/*
Portions of this software are based on Xlib and X Protocol Test Suite.
We have used this material under the terms of its copyright, which grants
free use, subject to the conditions below.  Note however that those
portions of this software that are based on the original Test Suite have
been significantly revised and that all such revisions are copyright (c)
1995 Applied Testing and Technology, Inc.  Insomuch as the proprietary
revisions cannot be separated from the freely copyable material, the net
result is that use of this software is governed by the ApTest copyright.

Copyright (c) 1990, 1991  X Consortium

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of the X Consortium shall not be
used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from the X Consortium.

Copyright 1990, 1991 by UniSoft Group Limited.

Permission to use, copy, modify, distribute, and sell this software and
its documentation for any purpose is hereby granted without fee,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of UniSoft not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.  UniSoft
makes no representations about the suitability of this software for any
purpose.  It is provided "as is" without express or implied warranty.
*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include	"xtest.h"
#include	"X11/Xlib.h"
#include	"X11/Xutil.h"
#include	"xtestlib.h"
#include	"pixval.h"

/* does this cursor match that of the window? */

int curofwin(display, cursor, window)
Display	*display;
Cursor	cursor;
Window	window;
{
	return CompareCursorWithWindow(display, window, cursor);
}

/* has this window the default cursor? */

int defcur(display, window)
Display	*display;
Window	window;
{
	Window root, wjunk, withdefault;
	int ijunk, rx, ry, res;
	unsigned int ujunk;

	if (!XQueryPointer(display, window, &root, &wjunk,
			&rx, &ry, &ijunk, &ijunk, &ujunk)) {
		delete("pointer not on same screen as window 0x%x.",
				(unsigned)window);
		return False;
	}
	withdefault = crechild(display, root, NULL);
	/* that window should have default Cursor, whatever that is */

	/*
	 * Note if a grab is active with a cursor specified then that's what
	 * we've got instead of our nice default cursor, so we fail.
	 * Also, if confine_to & grab then we may not get to our nice new
	 * window.
         * DO NOT USE THIS WHEN GRABS ARE ACTIVE.
	 */
	XWarpPointer(display, None, withdefault, 0, 0, 0, 0, 1, 1);
	res = CompareCurrentWithWindow(display, window);
	XWarpPointer(display, None, root, 0, 0, 0, 0, rx, ry);
	return res;
}

/* is the current cursor the same as that of window? */

int spriteiswin(display, window)
Display	*display;
Window	window;
{
	return CompareCurrentWithWindow(display, window);
}
